==> aria2-1.9.3.tar.xz: aria2-1.9.3/src/DHTMessageReceiver.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_DHT_MESSAGE_RECEIVER_H_
#define _D_DHT_MESSAGE_RECEIVER_H_

#include "common.h"
#include "SharedHandle.h"

namespace aria2 {

class DHTMessageTracker;
class DHTMessage;
class DHTConnection;
class DHTMessageFactory;
class DHTRoutingTable;

class Logger;

class DHTMessageReceiver {
private:
  SharedHandle<DHTMessageTracker> _tracker;

  SharedHandle<DHTConnection> _connection;

  SharedHandle<DHTMessageFactory> _factory;

  SharedHandle<DHTRoutingTable> _routingTable;

  Logger* _logger;

  SharedHandle<DHTMessage>
  handleUnknownMessage(const unsigned char* data, size_t length,
                       const std::string& remoteAddr, uint16_t remotePort);
public:
  DHTMessageReceiver(const SharedHandle<DHTMessageTracker>& tracker);
  
  ~DHTMessageReceiver();

  SharedHandle<DHTMessage> receiveMessage();

  void handleTimeout();

  const SharedHandle<DHTConnection>& getConnection() const
  {
    return _connection;
  }

  const SharedHandle<DHTMessageTracker>& getMessageTracker() const
  {
    return _tracker;
  }

  void setConnection(const SharedHandle<DHTConnection>& connection);

  void setMessageFactory(const SharedHandle<DHTMessageFactory>& factory);

  void setRoutingTable(const SharedHandle<DHTRoutingTable>& routingTable);
};

} // namespace aria2

#endif // _D_DHT_MESSAGE_RECEIVER_H_

==> aria2-1.10.6.tar.xz: aria2-1.10.6/src/DHTMessageReceiver.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_DHT_MESSAGE_RECEIVER_H
#define D_DHT_MESSAGE_RECEIVER_H

#include "common.h"
#include "SharedHandle.h"

namespace aria2 {

class DHTMessageTracker;
class DHTMessage;
class DHTConnection;
class DHTMessageFactory;
class DHTRoutingTable;

class Logger;

class DHTMessageReceiver {
private:
  SharedHandle<DHTMessageTracker> tracker_;

  SharedHandle<DHTConnection> connection_;

  SharedHandle<DHTMessageFactory> factory_;

  SharedHandle<DHTRoutingTable> routingTable_;

  Logger* logger_;

  SharedHandle<DHTMessage>
  handleUnknownMessage(const unsigned char* data, size_t length,
                       const std::string& remoteAddr, uint16_t remotePort);

  void onMessageReceived(const SharedHandle<DHTMessage>& message);
public:
  DHTMessageReceiver(const SharedHandle<DHTMessageTracker>& tracker);
  
  ~DHTMessageReceiver();

  SharedHandle<DHTMessage> receiveMessage();

  void handleTimeout();

  const SharedHandle<DHTConnection>& getConnection() const
  {
    return connection_;
  }

  const SharedHandle<DHTMessageTracker>& getMessageTracker() const
  {
    return tracker_;
  }

  void setConnection(const SharedHandle<DHTConnection>& connection);

  void setMessageFactory(const SharedHandle<DHTMessageFactory>& factory);

  void setRoutingTable(const SharedHandle<DHTRoutingTable>& routingTable);
};

} // namespace aria2

#endif // D_DHT_MESSAGE_RECEIVER_H
